The files in adios/ have been copied mostly unchanged from
https://github.com/NOAA-ORR-ERD/adios_oil_database/tree/master/adios_db and
should be covered by the CC0 license:
https://github.com/NOAA-ORR-ERD/adios_oil_database/blob/master/adios_db/setup.py .

The oils in oils.xz are scared from https://adios.orr.noaa.gov/oils using
harvest_oils.py. Re-run to update list.
